@@ -12,7 +12,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #include "moviedecoder.h"
 
@@ -315,8 +315,8 @@ bool MovieDecoder::initFilterGraph(enum AVPixelFormat pixfmt, int width, int hei
     m_filterGraph = avfilter_graph_alloc();
 
     QByteArray arguments("buffer=");
-    arguments += "video_size=" + QByteArray::number(width) + "x" + QByteArray::number(height) + ":";
-    arguments += "pix_fmt=" + QByteArray::number(pixfmt) + ":";
+    arguments += "video_size=" + QByteArray::number(width) + 'x' + QByteArray::number(height) + ':';
+    arguments += "pix_fmt=" + QByteArray::number(pixfmt) + ':';
     arguments += "time_base=1/1:pixel_aspect=0/1[in];";
     arguments += "[in]yadif[out];";
     arguments += "[out]buffersink";
